dfq_not_null

Function dfq_not_null 

pub fn dfq_not_null() -> Arc<NullRule>
Creates a rule that checks if values in a column are not null.

Arguments

  • column_name - The name of the column to check

Examples

use datafusion_quality::rules::column::dfq_not_null;
use datafusion_quality::RuleSet;

// Create a rule to check if age column is not null
let rule = dfq_not_null();
let mut ruleset = RuleSet::new();
ruleset.with_column_rule("age", rule);