Module schema

Module schema 

Structs

ColumnExistsRule
Rule that checks if a column exists in the schema
ColumnNullableRule
Rule that checks if a column is nullable
ColumnTypeRule
Rule that checks if a column has a specific data type

Functions

dfq_column_exists
Creates a rule that checks if a column exists in the schema
dfq_column_not_nullable
Creates a rule that checks if a column is not nullable
dfq_column_nullable
Creates a rule that checks if a column is nullable
dfq_column_type
Creates a rule that checks if a column has a specific data type