dfq_count

Function dfq_count 

pub fn dfq_count() -> Arc<CalculationRule>
Creates a rule that counts the number of rows in a column.

Examples

use datafusion_quality::rules::table::dfq_count;
use datafusion_quality::RuleSet;

// Create a rule to count the number of rows in the age column
let rule = dfq_count();
let mut ruleset = RuleSet::new();
ruleset.with_table_rule("age", rule, None);