pub fn dfq_stddev() -> Arc<CalculationRule>Expand description
Creates a rule that calculates the standard deviation of a column.
Examples
use datafusion_quality::rules::table::dfq_stddev;
use datafusion_quality::RuleSet;
// Create a rule to calculate the standard deviation of the age column
let rule = dfq_stddev();
let mut ruleset = RuleSet::new();
ruleset.with_table_rule("age", rule, None);