pub fn dfq_sum() -> Arc<CalculationRule>Expand description
Creates a rule that calculates the sum of a column.
Examples
use datafusion_quality::rules::table::dfq_sum;
use datafusion_quality::RuleSet;
// Create a rule to calculate the sum of the age column
let rule = dfq_sum();
let mut ruleset = RuleSet::new();
ruleset.with_table_rule("age", rule, None);