Structs
- Column
Exists Rule - Rule that checks if a column exists in the schema
- Column
Nullable Rule - Rule that checks if a column is nullable
- Column
Type Rule - Rule that checks if a column has a specific data type
Functions
- dfq_
column_ exists - Creates a rule that checks if a column exists in the schema
- dfq_
column_ not_ nullable - Creates a rule that checks if a column is not nullable
- dfq_
column_ nullable - Creates a rule that checks if a column is nullable
- dfq_
column_ type - Creates a rule that checks if a column has a specific data type