Skip to main contentModule table
Source - CalculationRule
- CustomAggregationRule
- Rule that applies a custom aggregation across the entire table
- CustomAggregationRuleBuilder
- NullCountRule
- Rule that counts null values in a column across the entire table
- CalculationType
- dfq_avg
- Creates a rule that calculates the average value of a column.
- dfq_count
- Creates a rule that counts the number of rows in a column.
- dfq_count_distinct
- Creates a rule that counts the number of distinct values in a column.
- dfq_covar_pop
- Creates a rule that calculates the population covariance of two columns.
- dfq_covar_samp
- Creates a rule that calculates the sample covariance of two columns.
- dfq_custom_agg
- dfq_first_value
- Returns the first value in the column.
- dfq_last_value
- Creates a rule that calculates the last value of a column.
- dfq_max
- Creates a rule that calculates the maximum value of a column.
- dfq_median
- Creates a rule that calculates the median of a column.
- dfq_min
- Creates a rule that calculates the minimum value of a column.
- dfq_not_null_count
- dfq_nth_value
- Returns the nth value in the column.
- dfq_null_count
- dfq_regr_avgx
- Creates a rule that calculates the average of x values in a column.
- dfq_regr_avgy
- Creates a rule that calculates the average of y values in a column.
- dfq_regr_count
- Creates a rule that calculates the number of rows in a column.
- dfq_regr_intercept
- Creates a rule that calculates the intercept of a linear regression.
- dfq_regr_r2
- Creates a rule that calculates the R-squared value of a linear regression.
- dfq_regr_slope
- Creates a rule that calculates the slope of a linear regression.
- dfq_regr_sxx
- Creates a rule that calculates the sum of squared deviations from the mean for x values.
- dfq_regr_sxy
- Creates a rule that calculates the sum of the products of deviations from the mean for x and y values.
- dfq_regr_syy
- Creates a rule that calculates the sum of squared deviations from the mean for y values.
- dfq_stddev
- Creates a rule that calculates the standard deviation of a column.
- dfq_stddev_pop
- Creates a rule that calculates the population standard deviation of a column.
- dfq_sum
- Creates a rule that calculates the sum of a column.
- dfq_var_pop
- Creates a rule that calculates the population variance of a column.
- dfq_var_samp
- Creates a rule that calculates the sample variance of a column.